# coding: utf-8

# flake8: noqa

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


__version__ = "0.0.1"

# import apis into sdk package
from woj.api.auth_api import AuthApi
from woj.api.problem_api import ProblemApi
from woj.api.submission_api import SubmissionApi
from woj.api.default_api import DefaultApi

# import ApiClient
from woj.api_response import ApiResponse
from woj.api_client import ApiClient
from woj.configuration import Configuration
from woj.exceptions import OpenApiException
from woj.exceptions import ApiTypeError
from woj.exceptions import ApiValueError
from woj.exceptions import ApiKeyError
from woj.exceptions import ApiAttributeError
from woj.exceptions import ApiException

# import models into sdk package
from woj.models.api_auth_get200_response import ApiAuthGet200Response
from woj.models.api_auth_send_post200_response import ApiAuthSendPost200Response
from woj.models.api_auth_send_post400_response import ApiAuthSendPost400Response
from woj.models.api_auth_send_post_request import ApiAuthSendPostRequest
from woj.models.api_me_get200_response import ApiMeGet200Response
from woj.models.api_problem_get200_response import ApiProblemGet200Response
from woj.models.api_problem_get200_response_problems_inner import ApiProblemGet200ResponseProblemsInner
from woj.models.api_problem_id_get200_response import ApiProblemIdGet200Response
from woj.models.api_problem_id_get200_response_problem import ApiProblemIdGet200ResponseProblem
from woj.models.api_problem_id_get200_response_problem_policy_inner import ApiProblemIdGet200ResponseProblemPolicyInner
from woj.models.api_problem_id_get200_response_problem_testcase_inner import ApiProblemIdGet200ResponseProblemTestcaseInner
from woj.models.api_submission_get200_response import ApiSubmissionGet200Response
from woj.models.api_submission_get200_response_submissions_inner import ApiSubmissionGet200ResponseSubmissionsInner
from woj.models.api_submission_id_get200_response import ApiSubmissionIdGet200Response
from woj.models.api_submission_id_get200_response_submission import ApiSubmissionIdGet200ResponseSubmission
from woj.models.api_submission_post200_response import ApiSubmissionPost200Response
from woj.models.api_submission_post_request import ApiSubmissionPostRequest
from woj.models.api_sys_get200_response import ApiSysGet200Response
from woj.models.api_sys_get200_response_cfg import ApiSysGet200ResponseCfg
from woj.models.api_sys_get200_response_stat import ApiSysGet200ResponseStat
