# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_submission_get200_response import ApiSubmissionGet200Response  # noqa: E501
from woj.rest import ApiException

class TestApiSubmissionGet200Response(unittest.TestCase):
    """ApiSubmissionGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiSubmissionGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSubmissionGet200Response`
        """
        model = woj.models.api_submission_get200_response.ApiSubmissionGet200Response()  # noqa: E501
        if include_optional :
            return ApiSubmissionGet200Response(
                submissions = [
                    woj.models._api_submission_get_200_response_submissions_inner._api_submission_get_200_response_submissions_inner(
                        id = '', 
                        code_lang = '', 
                        problem_id = '', 
                        status = 'running', 
                        submitter_id = '', 
                        score = 1.337, 
                        cost = 1.337, 
                        memory = 1.337, )
                    ]
            )
        else :
            return ApiSubmissionGet200Response(
                submissions = [
                    woj.models._api_submission_get_200_response_submissions_inner._api_submission_get_200_response_submissions_inner(
                        id = '', 
                        code_lang = '', 
                        problem_id = '', 
                        status = 'running', 
                        submitter_id = '', 
                        score = 1.337, 
                        cost = 1.337, 
                        memory = 1.337, )
                    ],
        )
        """

    def testApiSubmissionGet200Response(self):
        """Test ApiSubmissionGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
