# coding: utf-8

"""
    WASM OJ Wonderland API

    You can interact with WASM OJ Wonderland through this API  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: jacob@csie.cool
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import woj
from woj.models.api_submission_id_get200_response_submission import ApiSubmissionIdGet200ResponseSubmission  # noqa: E501
from woj.rest import ApiException

class TestApiSubmissionIdGet200ResponseSubmission(unittest.TestCase):
    """ApiSubmissionIdGet200ResponseSubmission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApiSubmissionIdGet200ResponseSubmission
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSubmissionIdGet200ResponseSubmission`
        """
        model = woj.models.api_submission_id_get200_response_submission.ApiSubmissionIdGet200ResponseSubmission()  # noqa: E501
        if include_optional :
            return ApiSubmissionIdGet200ResponseSubmission(
                id = '', 
                submitter_id = '', 
                status = 'running', 
                code = '', 
                code_lang = '', 
                problem_id = '', 
                compiler_version = '', 
                runner_version = '', 
                score = 1.337, 
                cost = 1.337, 
                memory = 1.337, 
                details = ''
            )
        else :
            return ApiSubmissionIdGet200ResponseSubmission(
                id = '',
                submitter_id = '',
                status = 'running',
                code = '',
                code_lang = '',
                problem_id = '',
                compiler_version = '',
                runner_version = '',
                score = 1.337,
                cost = 1.337,
                memory = 1.337,
                details = '',
        )
        """

    def testApiSubmissionIdGet200ResponseSubmission(self):
        """Test ApiSubmissionIdGet200ResponseSubmission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
